@@ -37,8 +37,13 @@ module.exports=function(app){
 
             rp.export(reportName,type,JSON.stringify(datas),JSON.stringify(parameters),
                 function(err,buff){
-                    var buffer= Buffer.from(buff, "hex");
-                    res.responseFile(buffer,type);
+                    if(err){
+                        res.send(err);
+                    }else{
+                        var buffer= Buffer.from(buff, "hex");
+                        res.responseFile(buffer,type);
+                    }
+                   
                 }
             );
         }
